==> lxqt-config_1.3.0.orig.tar.xz: lxqt-config-1.3.0/lxqt-config-monitor/translations/lxqt-config-monitor_el.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="el">
<context>
    <name>FastMenu</name>
    <message>
        <location filename="../fastmenu.ui" line="20"/>
        <source>Fast options</source>
        <translation>Γρήγορες επιλογές</translation>
    </message>
    <message>
        <location filename="../fastmenu.ui" line="40"/>
        <source> ❶ ❷ Extended view</source>
        <translation> ❶ ❷ Εκτεταμένη προβολή</translation>
    </message>
    <message>
        <location filename="../fastmenu.ui" line="45"/>
        <source> ❶ ❶ Unified view</source>
        <translation> ❶ ❶ Ενοποιημένη προβολή</translation>
    </message>
    <message>
        <location filename="../fastmenu.ui" line="50"/>
        <source> ❶     Only first</source>
        <translation> ❶     Μόνο πρώτη</translation>
    </message>
    <message>
        <location filename="../fastmenu.ui" line="55"/>
        <source>     ❷ Only second</source>
        <translation>     ❷ Μόνο δεύτερη</translation>
    </message>
</context>
<context>
    <name>LoadSettings</name>
    <message>
        <location filename="../loadsettings.cpp" line="98"/>
        <source>Default monitor settings has been applied. If you want change monitors settings, please, use lxqt-config-monitor.</source>
        <translation>Εφαρμόστηκαν οι ρυθμίσεις της προκαθορισμένης οθόνης. Αν θέλετε να αλλάξετε τις ρυθμίσεις των οθονών, παρακαλώ χρησιμοποιήστε το lxqt-config-monitor.</translation>
    </message>
</context>
<context>
    <name>ManageSavedSettings</name>
    <message>
        <location filename="../managesavedsettings.ui" line="14"/>
        <source>Monitor Settings</source>
        <translation>Ρυθμίσεις οθόνης</translation>
    </message>
    <message>
        <location filename="../managesavedsettings.ui" line="27"/>
        <source>Saved settings</source>
        <translation>Αποθηκευμένες ρυθμίσεις</translation>
    </message>
    <message>
        <location filename="../managesavedsettings.ui" line="38"/>
        <source>Rename</source>
        <translation>Μετονομασία</translation>
    </message>
    <message>
        <location filename="../managesavedsettings.ui" line="45"/>
        <source>Delete</source>
        <translation>Διαγραφή</translation>
    </message>
    <message>
        <location filename="../managesavedsettings.ui" line="52"/>
        <source>Apply</source>
        <translation>Εφαρμογή</translation>
    </message>
    <message>
        <location filename="../managesavedsettings.cpp" line="62"/>
        <source>None</source>
        <translation>Κανένα</translation>
    </message>
    <message>
        <location filename="../managesavedsettings.cpp" line="65"/>
        <source>Left</source>
        <translation>Αριστερά</translation>
    </message>
    <message>
        <location filename="../managesavedsettings.cpp" line="68"/>
        <source>Inverted</source>
        <translation>Ανεστραμμένα</translation>
    </message>
    <message>
        <location filename="../managesavedsettings.cpp" line="71"/>
        <source>Right</source>
        <translation>Δεξιά</translation>
    </message>
    <message>
        <location filename="../managesavedsettings.cpp" line="75"/>
        <location filename="../managesavedsettings.cpp" line="76"/>
        <source>True</source>
        <translation>Αληθές</translation>
    </message>
    <message>
        <location filename="../managesavedsettings.cpp" line="75"/>
        <location filename="../managesavedsettings.cpp" line="76"/>
        <source>False</source>
        <translation>Ψευδές</translation>
    </message>
    <message>
        <location filename="../managesavedsettings.cpp" line="136"/>
        <source>Name</source>
        <translation>Όνομα</translation>
    </message>
    <message>
        <location filename="../managesavedsettings.cpp" line="136"/>
        <source>Name:</source>
        <translation>Όνομα:</translation>
    </message>
</context>
<context>
    <name>MonitorPictureDialog</name>
    <message>
        <location filename="../monitorpicture.ui" line="27"/>
        <source>Keep monitors attached</source>
        <translation>Διατήρηση των οθονών συνδεδεμένων</translation>
    </message>
</context>
<context>
    <name>MonitorSettingsDialog</name>
    <message>
        <location filename="../monitorsettingsdialog.ui" line="14"/>
        <source>Monitor Settings</source>
        <translation>Ρυθμίσεις οθόνης</translation>
    </message>
    <message>
        <location filename="../monitorsettingsdialog.ui" line="70"/>
        <source>Settings</source>
        <translation>Ρυθμίσεις</translation>
    </message>
    <message>
        <location filename="../monitorsettingsdialog.cpp" line="106"/>
        <source>Fast Menu</source>
        <translation>Γρήγορο μενού</translation>
    </message>
    <message>
        <location filename="../monitorsettingsdialog.cpp" line="110"/>
        <source>Set position</source>
        <translation>Ορισμός θέσης</translation>
    </message>
    <message>
        <location filename="../monitorsettingsdialog.cpp" line="229"/>
        <source>Advanced settings</source>
        <translation>Προηγμένες ρυθμίσεις</translation>
    </message>
</context>
<context>
    <name>MonitorWidget</name>
    <message>
        <location filename="../monitorwidget.ui" line="21"/>
        <source>Setup</source>
        <translation>Εγκατάσταση</translation>
    </message>
    <message>
        <location filename="../monitorwidget.ui" line="29"/>
        <source> (x)</source>
        <translation> (x)</translation>
    </message>
    <message>
        <location filename="../monitorwidget.ui" line="45"/>
        <source> (y)</source>
        <translation> (y)</translation>
    </message>
    <message>
        <location filename="../monitorwidget.ui" line="78"/>
        <source>Resolution:</source>
        <translation>Ανάλυση:</translation>
    </message>
    <message>
        <location filename="../monitorwidget.ui" line="90"/>
        <source>Enable this display</source>
        <translation>Ενεργοποίηση αυτής της προβολής</translation>
    </message>
    <message>
        <location filename="../monitorwidget.ui" line="98"/>
        <source>This is my primary display</source>
        <translation>Αυτή είναι η πρωτεύουσα οθόνη μου</translation>
    </message>
    <message>
        <location filename="../monitorwidget.ui" line="103"/>
        <source>This screen extends another display</source>
        <translation>Αυτή η οθόνη επεκτείνει μια άλλη προβολή</translation>
    </message>
    <message>
        <location filename="../monitorwidget.ui" line="125"/>
        <source>Advanced</source>
        <translation>Προηγμένες</translation>
    </message>
    <message>
        <location filename="../monitorwidget.ui" line="146"/>
        <source>Refresh rate:</source>
        <translation>Ρυθμός ανανέωσης:</translation>
    </message>
    <message>
        <location filename="../monitorwidget.ui" line="153"/>
        <source>Rotation:</source>
        <translation>Περιστροφή:</translation>
    </message>
    <message>
        <location filename="../monitorwidget.ui" line="176"/>
        <source>Info</source>
        <translation>Πληροφορίες</translation>
    </message>
    <message>
        <location filename="../monitorwidget.ui" line="182"/>
        <source>Display information</source>
        <translation>Προβολή των πληροφοριών</translation>
    </message>
    <message>
        <location filename="../monitorwidget.cpp" line="129"/>
        <source>Name: %1
</source>
        <translation>Όνομα: %1
</translation>
    </message>
    <message>
        <location filename="../monitorwidget.cpp" line="130"/>
        <source>Vendor: %1
</source>
        <translation>Κατασκευαστής: %1
</translation>
    </message>
    <message>
        <location filename="../monitorwidget.cpp" line="131"/>
        <source>Serial: %1
</source>
        <translation>Σειραϊκός: %1
</translation>
    </message>
    <message>
        <location filename="../monitorwidget.cpp" line="132"/>
        <source>Display size: %1cm x %2cm
</source>
        <translation>Μέγεθος προβολής: %1εκ x %2εκ</translation>
    </message>
    <message>
        <location filename="../monitorwidget.cpp" line="133"/>
        <source>Serial number: %1
</source>
        <translation>Σειραϊκός αριθμός: %1
</translation>
    </message>
    <message>
        <location filename="../monitorwidget.cpp" line="134"/>
        <source>EISA device ID: %1
</source>
        <translation>Αναγνωριστικό συσκευής EISA: %1</translation>
    </message>
    <message>
        <location filename="../monitorwidget.cpp" line="154"/>
        <source>None</source>
        <translation>Ουδέν</translation>
    </message>
    <message>
        <location filename="../monitorwidget.cpp" line="155"/>
        <source>Left</source>
        <translation>Αριστερά</translation>
    </message>
    <message>
        <location filename="../monitorwidget.cpp" line="156"/>
        <source>Right</source>
        <translation>Δεξιά</translation>
    </message>
    <message>
        <location filename="../monitorwidget.cpp" line="157"/>
        <source>Inverted</source>
        <translation>Ανεστραμμένα</translation>
    </message>
    <message>
        <location filename="../monitorwidget.cpp" line="245"/>
        <source>%1 Hz</source>
        <translation>%1 Hz</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../settingsdialog.cpp" line="33"/>
        <source>Manage Saved Settings</source>
        <translation>Διαχείριση των αποθηκευμένων ρυθμίσεων</translation>
    </message>
</context>
<context>
    <name>SaveSettings</name>
    <message>
        <location filename="../savesettings.cpp" line="87"/>
        <source>Name</source>
        <translation>Όνομα</translation>
    </message>
    <message>
        <location filename="../savesettings.cpp" line="87"/>
        <source>Name:</source>
        <translation>Όνομα:</translation>
    </message>
</context>
<context>
    <name>TimeoutDialog</name>
    <message>
        <location filename="../timeoutdialog.ui" line="14"/>
        <source>Settings are changed</source>
        <translation>Οι ρυθμίσεις τροποποιήθηκαν</translation>
    </message>
    <message>
        <location filename="../timeoutdialog.ui" line="46"/>
        <source>Are the current settings OK for you?</source>
        <translation>Οι τρέχουσες ρυθμίσεις σας ικανοποιούν;</translation>
    </message>
    <message numerus="yes">
        <location filename="../timeoutdialog.cpp" line="63"/>
        <source>%n second(s) remaining</source>
        <translation>
            <numerusform>Υπολείπεται %n δευτερόλεπτο(α)</numerusform>
            <numerusform>Υπολείπεται %n δευτερόλεπτο(α)</numerusform>
        </translation>
    </message>
</context>
</TS>

==> lxqt-config-2.2.0.tar.xz: lxqt-config-2.2.0/lxqt-config-monitor/translations/lxqt-config-monitor_el.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="el">
<context>
    <name>FastMenu</name>
    <message>
        <location filename="../fastmenu.ui" line="20"/>
        <source>Fast options</source>
        <translation>Γρήγορες επιλογές</translation>
    </message>
    <message>
        <location filename="../fastmenu.ui" line="40"/>
        <source> ❶ ❷ Extended view</source>
        <translation> ❶ ❷ Εκτεταμένη προβολή</translation>
    </message>
    <message>
        <location filename="../fastmenu.ui" line="45"/>
        <source> ❶ ❶ Unified view</source>
        <translation> ❶ ❶ Ενοποιημένη προβολή</translation>
    </message>
    <message>
        <location filename="../fastmenu.ui" line="50"/>
        <source> ❶     Only first</source>
        <translation> ❶     Μόνο πρώτη</translation>
    </message>
    <message>
        <location filename="../fastmenu.ui" line="55"/>
        <source>     ❷ Only second</source>
        <translation>     ❷ Μόνο δεύτερη</translation>
    </message>
</context>
<context>
    <name>LoadSettings</name>
    <message>
        <location filename="../loadsettings.cpp" line="97"/>
        <source>Default monitor settings applied.</source>
        <translation>Εφαρμόστηκαν προεπιλεγμένες ρυθμίσεις οθόνης.</translation>
    </message>
    <message>
        <location filename="../loadsettings.cpp" line="98"/>
        <source>Adjust your screens with LXQt Monitor Settings.</source>
        <translation>Ρυθμίστε τις οθόνες σας με τις ρυθμίσεις οθόνης LXQt.</translation>
    </message>
    <message>
        <location filename="../loadsettings.cpp" line="107"/>
        <source>lxqt-config-monitor: Settings applied.</source>
        <translation>lxqt-config-monitor: Οι ρυθμίσεις εφαρμόστηκαν.</translation>
    </message>
    <message>
        <location filename="../loadsettings.cpp" line="109"/>
        <source>lxqt-config-monitor: Settings not applied.
If this is a Wayland compositor, you could try kanshi to configure your monitor(s).</source>
        <translation>lxqt-config-monitor: Δεν εφαρμόστηκαν οι ρυθμίσεις.
Αν αυτός είναι ένας συνθέτης Wayland, θα μπορούσατε να δοκιμάσετε το kanshi για να διαμορφώσετε το(α) μόνιτορ σας.</translation>
    </message>
</context>
<context>
    <name>ManageSavedSettings</name>
    <message>
        <location filename="../managesavedsettings.ui" line="14"/>
        <source>Monitor Settings</source>
        <translation>Ρυθμίσεις οθόνης</translation>
    </message>
    <message>
        <location filename="../managesavedsettings.ui" line="27"/>
        <source>Saved settings</source>
        <translation>Αποθηκευμένες ρυθμίσεις</translation>
    </message>
    <message>
        <location filename="../managesavedsettings.ui" line="45"/>
        <source>Rename</source>
        <translation>Μετονομασία</translation>
    </message>
    <message>
        <location filename="../managesavedsettings.ui" line="52"/>
        <source>Delete</source>
        <translation>Διαγραφή</translation>
    </message>
    <message>
        <location filename="../managesavedsettings.cpp" line="66"/>
        <source>None</source>
        <translation>Κανένα</translation>
    </message>
    <message>
        <location filename="../managesavedsettings.cpp" line="69"/>
        <source>Left</source>
        <translation>Αριστερά</translation>
    </message>
    <message>
        <location filename="../managesavedsettings.cpp" line="72"/>
        <source>Inverted</source>
        <translation>Ανεστραμμένα</translation>
    </message>
    <message>
        <location filename="../managesavedsettings.cpp" line="75"/>
        <source>Right</source>
        <translation>Δεξιά</translation>
    </message>
    <message>
        <location filename="../managesavedsettings.cpp" line="79"/>
        <location filename="../managesavedsettings.cpp" line="80"/>
        <source>True</source>
        <translation>Αληθές</translation>
    </message>
    <message>
        <location filename="../managesavedsettings.cpp" line="79"/>
        <location filename="../managesavedsettings.cpp" line="80"/>
        <source>False</source>
        <translation>Ψευδές</translation>
    </message>
    <message>
        <location filename="../managesavedsettings.cpp" line="139"/>
        <source>Name</source>
        <translation>Όνομα</translation>
    </message>
    <message>
        <location filename="../managesavedsettings.cpp" line="139"/>
        <source>Name:</source>
        <translation>Όνομα:</translation>
    </message>
    <message>
        <location filename="../managesavedsettings.cpp" line="172"/>
        <source>Settings Activation Failed</source>
        <translation>Αποτυχία ενεργοποίησης των ρυθμίσεων</translation>
    </message>
    <message>
        <location filename="../managesavedsettings.cpp" line="173"/>
        <source>Selected settings cannot be applied with currently active monitors.

Please choose from the highlighted configurations.</source>
        <translation>Οι επιλεγμένες ρυθμίσεις δεν μπορούν να εφαρμοστούν στις ενεργές οθόνες.

Παρακαλώ επιλέξτε μεταξύ των επισημασμένων διαμορφώσεων.</translation>
    </message>
</context>
<context>
    <name>MonitorPictureDialog</name>
    <message>
        <location filename="../monitorpicture.ui" line="27"/>
        <source>Keep monitors attached</source>
        <translation>Διατήρηση των οθονών συνδεδεμένων</translation>
    </message>
</context>
<context>
    <name>MonitorSettingsDialog</name>
    <message>
        <location filename="../monitorsettingsdialog.ui" line="14"/>
        <source>Monitor Settings</source>
        <translation>Ρυθμίσεις οθόνης</translation>
    </message>
    <message>
        <location filename="../monitorsettingsdialog.ui" line="70"/>
        <source>Settings</source>
        <translation>Ρυθμίσεις</translation>
    </message>
    <message>
        <location filename="../monitorsettingsdialog.cpp" line="62"/>
        <source>Platform Unsupported</source>
        <translation>Μη υποστηριζόμενο πλατύβαθρο</translation>
    </message>
    <message>
        <location filename="../monitorsettingsdialog.cpp" line="63"/>
        <source>LXQt monitor settings are currently unsupported under this wayland compositor.

You can configure your monitor(s) with kanshi.</source>
        <translation>Οι ρυθμίσεις οθόνης του LXQt δεν υποστηρίζονται για τον συνθέτη wayland.

Μπορείτε να διαμορφώσετε την οθόνη σας με το kanshi.</translation>
    </message>
    <message>
        <location filename="../monitorsettingsdialog.cpp" line="118"/>
        <source>Fast Menu</source>
        <translation>Γρήγορο μενού</translation>
    </message>
    <message>
        <location filename="../monitorsettingsdialog.cpp" line="122"/>
        <source>Set position</source>
        <translation>Ορισμός θέσης</translation>
    </message>
    <message>
        <location filename="../monitorsettingsdialog.cpp" line="241"/>
        <source>Advanced settings</source>
        <translation>Προηγμένες ρυθμίσεις</translation>
    </message>
</context>
<context>
    <name>MonitorWidget</name>
    <message>
        <location filename="../monitorwidget.ui" line="21"/>
        <source>Setup</source>
        <translation>Εγκατάσταση</translation>
    </message>
    <message>
        <location filename="../monitorwidget.ui" line="64"/>
        <source> (x)</source>
        <translation> (x)</translation>
    </message>
    <message>
        <location filename="../monitorwidget.ui" line="80"/>
        <source> (y)</source>
        <translation> (y)</translation>
    </message>
    <message>
        <location filename="../monitorwidget.ui" line="36"/>
        <source>Resolution:</source>
        <translation>Ανάλυση:</translation>
    </message>
    <message>
        <location filename="../monitorwidget.ui" line="27"/>
        <source>Enable this display</source>
        <translation>Ενεργοποίηση αυτής της προβολής</translation>
    </message>
    <message>
        <location filename="../monitorwidget.ui" line="49"/>
        <source>This is my primary display</source>
        <translation>Αυτή είναι η πρωτεύουσα οθόνη μου</translation>
    </message>
    <message>
        <location filename="../monitorwidget.ui" line="54"/>
        <source>This screen extends another display</source>
        <translation>Αυτή η οθόνη επεκτείνει μια άλλη προβολή</translation>
    </message>
    <message>
        <location filename="../monitorwidget.ui" line="125"/>
        <source>Advanced</source>
        <translation>Προηγμένες</translation>
    </message>
    <message>
        <location filename="../monitorwidget.ui" line="143"/>
        <source>Refresh rate:</source>
        <translation>Ρυθμός ανανέωσης:</translation>
    </message>
    <message>
        <location filename="../monitorwidget.ui" line="133"/>
        <source>Rotation:</source>
        <translation>Περιστροφή:</translation>
    </message>
    <message>
        <location filename="../monitorwidget.ui" line="176"/>
        <source>Info</source>
        <translation>Πληροφορίες</translation>
    </message>
    <message>
        <location filename="../monitorwidget.ui" line="182"/>
        <source>Display information</source>
        <translation>Προβολή των πληροφοριών</translation>
    </message>
    <message>
        <location filename="../monitorwidget.cpp" line="129"/>
        <source>Name: %1
</source>
        <translation>Όνομα: %1
</translation>
    </message>
    <message>
        <location filename="../monitorwidget.cpp" line="130"/>
        <source>Vendor: %1
</source>
        <translation>Κατασκευαστής: %1
</translation>
    </message>
    <message>
        <location filename="../monitorwidget.cpp" line="131"/>
        <source>Serial: %1
</source>
        <translation>Σειραϊκός: %1
</translation>
    </message>
    <message>
        <location filename="../monitorwidget.cpp" line="132"/>
        <source>Display size: %1cm x %2cm
</source>
        <translation>Μέγεθος προβολής: %1εκ x %2εκ
</translation>
    </message>
    <message>
        <location filename="../monitorwidget.cpp" line="133"/>
        <source>Serial number: %1
</source>
        <translation>Σειραϊκός αριθμός: %1
</translation>
    </message>
    <message>
        <location filename="../monitorwidget.cpp" line="134"/>
        <source>EISA device ID: %1
</source>
        <translation>Αναγνωριστικό συσκευής EISA: %1
</translation>
    </message>
    <message>
        <location filename="../monitorwidget.cpp" line="155"/>
        <source>None</source>
        <translation>Ουδέν</translation>
    </message>
    <message>
        <location filename="../monitorwidget.cpp" line="156"/>
        <source>Left</source>
        <translation>Αριστερά</translation>
    </message>
    <message>
        <location filename="../monitorwidget.cpp" line="157"/>
        <source>Right</source>
        <translation>Δεξιά</translation>
    </message>
    <message>
        <location filename="../monitorwidget.cpp" line="158"/>
        <source>Inverted</source>
        <translation>Ανεστραμμένα</translation>
    </message>
    <message>
        <location filename="../monitorwidget.cpp" line="248"/>
        <source>%1 Hz</source>
        <translation>%1 Hz</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../settingsdialog.cpp" line="33"/>
        <source>Manage Saved Settings</source>
        <translation>Διαχείριση των αποθηκευμένων ρυθμίσεων</translation>
    </message>
</context>
<context>
    <name>SaveSettings</name>
    <message>
        <location filename="../savesettings.cpp" line="87"/>
        <source>Name</source>
        <translation>Όνομα</translation>
    </message>
    <message>
        <location filename="../savesettings.cpp" line="87"/>
        <source>Name:</source>
        <translation>Όνομα:</translation>
    </message>
</context>
<context>
    <name>TimeoutDialog</name>
    <message>
        <location filename="../timeoutdialog.ui" line="14"/>
        <source>Settings are changed</source>
        <translation>Οι ρυθμίσεις τροποποιήθηκαν</translation>
    </message>
    <message>
        <location filename="../timeoutdialog.ui" line="46"/>
        <source>Are the current settings OK for you?</source>
        <translation>Οι τρέχουσες ρυθμίσεις σας ικανοποιούν;</translation>
    </message>
    <message numerus="yes">
        <location filename="../timeoutdialog.cpp" line="63"/>
        <source>%n second(s) remaining</source>
        <translation>
            <numerusform>Υπολείπεται %n δευτερόλεπτο</numerusform>
            <numerusform>Υπολείπονται %n δευτερόλεπτα</numerusform>
        </translation>
    </message>
</context>
</TS>
